You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@river.apache.org by si...@apache.org on 2012/10/27 10:20:46 UTC

svn commit: r1402756 - in /river/jtsk/trunk/src/net/jini/io: MarshalInputStream.java MarshalOutputStream.java MarshalledInstance.java

Author: sijskes
Date: Sat Oct 27 08:20:46 2012
New Revision: 1402756

URL: http://svn.apache.org/viewvc?rev=1402756&view=rev
Log:
RIVER-336

Modified:
    river/jtsk/trunk/src/net/jini/io/MarshalInputStream.java
    river/jtsk/trunk/src/net/jini/io/MarshalOutputStream.java
    river/jtsk/trunk/src/net/jini/io/MarshalledInstance.java

Modified: river/jtsk/trunk/src/net/jini/io/MarshalInputStream.java
URL: http://svn.apache.org/viewvc/river/jtsk/trunk/src/net/jini/io/MarshalInputStream.java?rev=1402756&r1=1402755&r2=1402756&view=diff
==============================================================================
--- river/jtsk/trunk/src/net/jini/io/MarshalledInstance.java (original)
+++ river/jtsk/trunk/src/net/jini/io/MarshalledInstance.java Sat Oct 27 08:20:46 2012
@@ -306,7 +306,7 @@ public class MarshalledInstance implemen
      *
      * @param defaultLoader the class loader value (possibly
      *	      <code>null</code>) to pass as the <code>defaultLoader</code>
-     *        argument to <code>RMIClassLoader</code> methods
+     *        argument to <code>RiverClassLoader</code> methods
      * @param verifyCodebaseIntegrity if <code>true</code> then
      *        codebase integrity is verified, otherwise code base
      *        integrity is not verified
--- river/jtsk/trunk/src/net/jini/io/MarshalInputStream.java (original)
+++ river/jtsk/trunk/src/net/jini/io/MarshalInputStream.java Sat Oct 27 08:20:46 2012
@@ -23,19 +23,18 @@ import java.io.InputStream;
 import java.io.InvalidObjectException;
 import java.io.ObjectInputStream;
 import java.io.ObjectStreamClass;
-import java.net.MalformedURLException;
-import java.rmi.server.RMIClassLoader;
 import java.util.Collection;
 import java.util.HashMap;
 import java.util.Map;
 import net.jini.loader.ClassLoading;
+import net.jini.loader.RiverClassLoader;
 import net.jini.security.Security;
 
 /**
  * An extension of <code>ObjectInputStream</code> that implements the
  * dynamic class loading semantics of Java(TM) Remote Method
  * Invocation (Java RMI) argument and result
- * unmarshalling (using {@link RMIClassLoader}).  A
+ * unmarshalling (using {@link RiverClassLoader}).  A
  * <code>MarshalInputStream</code> is intended to read data written by
  * a corresponding {@link MarshalOutputStream}.
  *
@@ -46,10 +45,10 @@ import net.jini.security.Security;
  * class descriptors in the stream using {@link ClassLoading#loadClass
  * ClassLoading.loadClass} and {@link ClassLoading#loadProxyClass
  * ClassLoading.loadProxyClass} (which, in turn, use {@link
  * RMIClassLoader#loadClass(String,String,ClassLoader)
  * RMIClassLoader.loadClass} and {@link
  * RMIClassLoader#loadProxyClass(String,String[],ClassLoader)
  * RMIClassLoader.loadProxyClass}), optionally with codebase
  * annotation strings written by a <code>MarshalOutputStream</code>.
  *
  * <p>By default, a <code>MarshalInputStream</code> ignores all
@@ -46,10 +45,10 @@ import net.jini.security.Security;
  * ClassLoading.loadClass} and {@link ClassLoading#loadProxyClass
  * ClassLoading.loadProxyClass} (which, in turn, use {@link
- * RMIClassLoader#loadClass(String,String,ClassLoader)
- * RMIClassLoader.loadClass} and {@link
- * RMIClassLoader#loadProxyClass(String,String[],ClassLoader)
- * RMIClassLoader.loadProxyClass}), optionally with codebase
+ * RiverClassLoader#loadClass(String,String,ClassLoader)
+ * RiverClassLoader.loadClass} and {@link
+ * RiverClassLoader#loadProxyClass(String,String[],ClassLoader)
+ * RiverClassLoader.loadProxyClass}), optionally with codebase
  * annotation strings written by a <code>MarshalOutputStream</code>.
  *

Modified: river/jtsk/trunk/src/net/jini/io/MarshalOutputStream.java
URL: http://svn.apache.org/viewvc/river/jtsk/trunk/src/net/jini/io/MarshalOutputStream.java?rev=1402756&r1=1402755&r2=1402756&view=diff
==============================================================================
--- river/jtsk/trunk/src/net/jini/io/MarshalOutputStream.java (original)
+++ river/jtsk/trunk/src/net/jini/io/MarshalOutputStream.java Sat Oct 27 08:20:46 2012
@@ -21,14 +21,14 @@ package net.jini.io;
 import java.io.IOException;
 import java.io.ObjectOutputStream;
 import java.io.OutputStream;
-import java.rmi.server.RMIClassLoader;
 import java.util.Collection;
+import net.jini.loader.RiverClassLoader;
 
 /**
  * An extension of <code>ObjectOutputStream</code> that implements the
  * dynamic class loading semantics of Java(TM) Remote Method Invocation
  * (Java RMI) argument and result
- * marshalling (using {@link RMIClassLoader}).  A
+ * marshalling (using {@link RiverClassLoader}).  A
  * <code>MarshalOutputStream</code> writes data that is intended to be
  * written by a corresponding {@link MarshalInputStream}.
  *
@@ -37,8 +37,8 @@ import java.util.Collection;
  * ObjectOutputStream#annotateClass annotateClass} and {@link
  * ObjectOutputStream#annotateProxyClass annotateProxyClass} to
  * annotate class descriptors in the stream with codebase strings
  * obtained using {@link RMIClassLoader#getClassAnnotation
  * RMIClassLoader.getClassAnnotation}.
  *
  * <p><code>MarshalOutputStream</code> writes class annotations to its
  * own stream; a subclass may override the {@link #writeAnnotation
@@ -111,8 +111,8 @@ public class MarshalOutputStream
      * <p><code>MarshalOutputStream</code> implements this method as
      * follows:
      *
      * <p>This method invokes {@link RMIClassLoader#getClassAnnotation
      * RMIClassLoader.getClassAnnotation} with <code>cl</code> to get
      * the appropriate class annotation string value (possibly
      * <code>null</code>), and then it invokes this stream's {@link
      * #writeAnnotation writeAnnotation} method with that string to
@@ -127,7 +127,7 @@ public class MarshalOutputStream
      * <code>null</code>
      **/
     protected void annotateClass(Class cl) throws IOException {
-	writeAnnotation(RMIClassLoader.getClassAnnotation(cl));
+	writeAnnotation(RiverClassLoader.getClassAnnotation(cl));
     }
 
     /**
@@ -137,8 +137,8 @@ public class MarshalOutputStream
      * <p><code>MarshalOutputStream</code> implements this method as
      * follows:
      *
      * <p>This method invokes {@link RMIClassLoader#getClassAnnotation
      * RMIClassLoader.getClassAnnotation} with <code>cl</code> to get
      * the appropriate class annotation string value (possibly
      * <code>null</code>), and then it invokes this stream's {@link
      * #writeAnnotation writeAnnotation} method with that string to
@@ -153,7 +153,7 @@ public class MarshalOutputStream
      * <code>null</code>
      **/
     protected void annotateProxyClass(Class cl) throws IOException {
-	writeAnnotation(RMIClassLoader.getClassAnnotation(cl));
+	writeAnnotation(RiverClassLoader.getClassAnnotation(cl));
     }
 
     /**
@@ -37,8 +37,8 @@ import java.util.Collection;
  * ObjectOutputStream#annotateProxyClass annotateProxyClass} to
  * annotate class descriptors in the stream with codebase strings
- * obtained using {@link RMIClassLoader#getClassAnnotation
- * RMIClassLoader.getClassAnnotation}.
+ * obtained using {@link RiverClassLoader#getClassAnnotation
+ * RiverClassLoader.getClassAnnotation}.
  *
  * <p><code>MarshalOutputStream</code> writes class annotations to its
@@ -111,8 +111,8 @@ public class MarshalOutputStream
      * follows:
      *
-     * <p>This method invokes {@link RMIClassLoader#getClassAnnotation
-     * RMIClassLoader.getClassAnnotation} with <code>cl</code> to get
+     * <p>This method invokes {@link RiverClassLoader#getClassAnnotation
+     * RiverClassLoader.getClassAnnotation} with <code>cl</code> to get
      * the appropriate class annotation string value (possibly
      * <code>null</code>), and then it invokes this stream's {@link
@@ -137,8 +137,8 @@ public class MarshalOutputStream
      * follows:
      *
-     * <p>This method invokes {@link RMIClassLoader#getClassAnnotation
-     * RMIClassLoader.getClassAnnotation} with <code>cl</code> to get
+     * <p>This method invokes {@link RiverClassLoader#getClassAnnotation
+     * RiverClassLoader.getClassAnnotation} with <code>cl</code> to get
      * the appropriate class annotation string value (possibly
      * <code>null</code>), and then it invokes this stream's {@link

Modified: river/jtsk/trunk/src/net/jini/io/MarshalledInstance.java
URL: http://svn.apache.org/viewvc/river/jtsk/trunk/src/net/jini/io/MarshalledInstance.java?rev=1402756&r1=1402755&r2=1402756&view=diff
==============================================================================